==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/UnknownClass.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o.query;

namespace com.db4o.test
{

	public class UnknownClass
	{

        public void store(){
            Tester.store(new Atom());

//            Tester.store(new UnknownClass());
//            Tester.commit();
//            Query q = Tester.query();
//            q.constrain(typeof(UnknownClass));
//            ObjectSet objectSet = q.execute();
//            while(objectSet.hasNext()){
//                Tester.delete(objectSet.next());
//            }
//            Tester.commit();

        }
    
        public void test(){
            Query q = Tester.query();
            q.constrain(typeof(UnknownClass));
            Tester.ensure(q.execute().size() == 0);
        }

    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/UnknownClass.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o.query;

namespace com.db4o.test
{

	public class UnknownClass
	{

        public void Store(){
            Tester.Store(new Atom());

//            Tester.Store(new UnknownClass());
//            Tester.Commit();
//            Query q = Tester.Query();
//            q.Constrain(typeof(UnknownClass));
//            ObjectSet objectSet = q.Execute();
//            while(objectSet.HasNext()){
//                Tester.Delete(objectSet.Next());
//            }
//            Tester.Commit();

        }
    
        public void Test(){
            Query q = Tester.Query();
            q.Constrain(typeof(UnknownClass));
            Tester.Ensure(q.Execute().Size() == 0);
        }

    }
}
